X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/a858bf15e799045a63e30d74dda1c0b7548daf48..aed2f8545d0f6c83a61d004a423d533013cfa13e:/RapsysUserBundle.php

diff --git a/RapsysUserBundle.php b/RapsysUserBundle.php
index 627ad61..087ac87 100644
--- a/RapsysUserBundle.php
+++ b/RapsysUserBundle.php
@@ -1,17 +1,39 @@
-<?php
+<?php declare(strict_types=1);
+
+/*
+ * This file is part of the Rapsys UserBundle package.
+ *
+ * (c) Raphaël Gertz <symfony@rapsys.eu>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
 
 namespace Rapsys\UserBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Rapsys\UserBundle\DependencyInjection\RapsysUserExtension;
+
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
+/**
+ * {@inheritdoc}
+ */
 class RapsysUserBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
 	 * @return string The bundle alias
 	 */
-    public static function getAlias(): string {
+	public static function getAlias(): string {
 		//With namespace
 		if ($npos = strrpos(static::class, '\\')) {
 			//Set name pos
@@ -31,7 +53,17 @@ class RapsysUserBundle extends Bundle {
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
-    }
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.5.1';
+	}
 }